==> carbon-component-mapper-3.11.0.tgz: package/esm/radio/radio.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import RadioButtonGroup from "carbon-components-react/es/components/RadioButtonGroup/RadioButtonGroup.js";
import RadioButton from "carbon-components-react/es/components/RadioButton/RadioButton.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Radio = function Radio(props) {
  var _useFieldApi = useFieldApi(prepareProps(_objectSpread({
    type: 'radio'
  }, props))),
      labelText = _useFieldApi.labelText,
      disabled = _useFieldApi.disabled,
      input = _useFieldApi.input,
      options = _useFieldApi.options,
      FormGroupProps = _useFieldApi.FormGroupProps,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      rest = _objectWithoutProperties(_useFieldApi, ["labelText", "disabled", "input", "options", "FormGroupProps", "helperText", "meta", "validateOnMount"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: labelText
  }, FormGroupProps), /*#__PURE__*/React.createElement(RadioButtonGroup, _extends({}, input, {
    valueSelected: input.value,
    disabled: disabled
  }, rest), options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioButton, _extends({
      key: option.value,
      disabled: disabled,
      labelText: option.label,
      value: option.value
    }, option));
  })), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Radio.propTypes = {
  FormGroupProps: PropTypes.object,
  isDisabled: PropTypes.bool,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
  }))
};
export default Radio;

==> carbon-component-mapper-3.11.4.tgz: package/esm/radio/radio.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from "carbon-components-react/es/components/FormGroup/FormGroup.js";
import RadioButtonGroup from "carbon-components-react/es/components/RadioButtonGroup/RadioButtonGroup.js";
import RadioButton from "carbon-components-react/es/components/RadioButton/RadioButton.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Radio = function Radio(_ref) {
  var component = _ref.component,
      props = _objectWithoutProperties(_ref, ["component"]);

  var _useFieldApi = useFieldApi(prepareProps(props)),
      labelText = _useFieldApi.labelText,
      disabled = _useFieldApi.disabled,
      input = _useFieldApi.input,
      options = _useFieldApi.options,
      FormGroupProps = _useFieldApi.FormGroupProps,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      rest = _objectWithoutProperties(_useFieldApi, ["labelText", "disabled", "input", "options", "FormGroupProps", "helperText", "meta", "validateOnMount"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: labelText
  }, FormGroupProps), /*#__PURE__*/React.createElement(RadioButtonGroup, _extends({}, input, {
    valueSelected: input.value,
    disabled: disabled
  }, rest), options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioButton, _extends({
      key: option.value,
      disabled: disabled,
      labelText: option.label,
      value: option.value
    }, option));
  })), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Radio.propTypes = {
  component: PropTypes.string,
  FormGroupProps: PropTypes.object,
  isDisabled: PropTypes.bool,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
  }))
};
export default Radio;
